@@ -1,15 +1,16 @@
-#!/usr/bin/env python
-
 """test_setup
 ----------------------------------
 
 Tests for `skbuild.setup` function.
 """
 
+from __future__ import annotations
+
 import os
 import pprint
 import sys
 import textwrap
+from collections.abc import Sequence
 from unittest.mock import patch
 
 import py.path
@@ -64,7 +65,8 @@ def test_distribution_is_pure(distribution_type, tmpdir):
             """
         )
     else:
-        raise Exception(f"Unknown distribution_type: {distribution_type}")
+        msg = f"Unknown distribution_type: {distribution_type}"
+        raise Exception(msg)
 
     platform = get_platform()
     original_write_test_cmakelist = platform.write_test_cmakelist
@@ -80,7 +82,7 @@ def test_distribution_is_pure(distribution_type, tmpdir):
                 description="test object returned by setup function",
                 author="The scikit-build team",
                 license="MIT",
-                **skbuild_setup_kwargs,
+                **skbuild_setup_kwargs,  # type: ignore[arg-type]
             )
             assert issubclass(distribution.__class__, (distutils_Distribution, setuptool_Distribution))
             assert is_pure == distribution.is_pure()
@@ -344,9 +346,7 @@ def test_setup_requires_keyword_include_cmake(mocker, capsys):
             license="MIT",
             setup_requires=[{setup_requires}]
         )
-        """.format(
-                setup_requires=",".join(["'%s'" % package for package in setup_requires])
-            )
+        """.format(setup_requires=",".join([f"'{package}'" for package in setup_requires]))
         )
     )
     tmp_dir.join("CMakeLists.txt").write(
@@ -541,7 +541,6 @@ def test_py_modules_keyword(distribution_type, capsys, caplog):
         ([""], "file.py", "file.py"),
         ([], "foo/file.py", "foo/file.py"),
         (["foo"], "", ""),
-        (["foo"], "", ""),
         (["foo"], "foo/file.py", "file.py"),
         (["foo"], "foo\\file.py", "file.py"),
         (["foo", "bar"], "foo/file.py", "foo/file.py"),
@@ -773,22 +772,25 @@ def test_setup_inputs(
     )
 
     # List path types: 'c', 'cm', 'h', 'p' or 'pm'
+    path_types: Sequence[str]
     try:
-        path_types = list(
-            zip(
-                *filter(
-                    lambda i: i[1],
-                    [
-                        ("c", has_cmake_package),
-                        ("cm", has_cmake_module),
-                        ("h", has_hybrid_package),
-                        ("p", has_pure_package),
-                        ("pm", has_pure_module),
-                    ],
+        path_types = next(
+            iter(
+                zip(
+                    *filter(
+                        lambda i: i[1],
+                        [
+                            ("c", has_cmake_package),
+                            ("cm", has_cmake_module),
+                            ("h", has_hybrid_package),
+                            ("p", has_pure_package),
+                            ("pm", has_pure_module),
+                        ],
+                    )
                 )
             )
-        )[0]
-    except IndexError:
+        )
+    except StopIteration:
         path_types = []
 
     def select_paths(annotated_paths):
@@ -827,8 +829,8 @@ def test_setup_inputs(
             ("p", "pure/data/pure.dat"),
         ]
     ):
-        assert _type in ["p", "pm", "h"]
-        root = package_base if (_type == "p" or _type == "pm") else cmake_source_dir
+        assert _type in {"p", "pm", "h"}
+        root = package_base if _type in {"p", "pm"} else cmake_source_dir
         tmp_dir.ensure(os.path.join(root, path))
 
     # Do not call the real setup function. Instead, replace it with
@@ -839,9 +841,9 @@ def test_setup_inputs(
     def _pprint(desc, value=None):
         print(
             "-----------------\n"
-            "{}:\n"
+            f"{desc}:\n"
             "\n"
-            "{}\n".format(desc, pprint.pformat(setup_kw.get(desc, {}) if value is None else value, indent=2))
+            f"{pprint.pformat(setup_kw.get(desc, {}) if value is None else value, indent=2)}\n"
         )
 
     with execute_setup_py(tmp_dir, ["build"], disable_languages_test=True):
@@ -915,13 +917,11 @@ def test_setup_inputs(
         _pprint("py_modules")
 
         # scripts
-        expected_scripts = []
-        _pprint("expected_scripts", expected_scripts)
+        _pprint("expected_scripts", [])
         _pprint("scripts")
 
         # data_files
-        expected_data_files = []
-        _pprint("expected_data_files", expected_data_files)
+        _pprint("expected_data_files", [])
         _pprint("data_files")
 
         assert sorted(setup_kw["packages"]) == sorted(expected_packages)
